@@ -390,15 +390,23 @@ class SQLInsert ():
 
 		self._sql_insert = table
 
-	def addDictValues (self, col_dict_list):
+	def addDictValues (self, col_dict):
+		
+		# Confirm the data is within a list
+		if not isinstance(col_dict, dict): raise Exception('Values must be stored within a dict')
+
+		# Add the insert from a dict
+		sql_values = SQLValues.fromColDictValues(self._sql_insert, col_dict)
+		self._sql_values.append(sql_values)
+
+	def addListValues (self, col_dict_list):
 		
 		# Confirm the data is within a list
 		if not isinstance(col_dict_list, list): raise Exception('Values must be stored within a List')
 
 		# Add the insert from a list of dict
 		for col_dict in col_dict_list:
-			sql_values = SQLValues.fromColDictValues(self._sql_insert, col_dict)
-			self._sql_values.append(sql_values)
+			self.addDictValues(col_dict)
 
 	def addDataFrameValues (self, dataframe):
 
@@ -406,7 +414,7 @@ class SQLInsert ():
 		col_dict_list = dataframe.to_dict('records')
 
 		# Add the values
-		self.addDictValues(col_dict_list)
+		self.addListValues(col_dict_list)
 		
 class SQLValues (dict):
 	def __init__(self, *arg, **kw):
